General Framework
=================

Core classes for location, time, and status tracking.

.. module:: PASS.general_framework

general_classes
---------------

Location and time management classes.

.. automodule:: PASS.general_framework.general_classes
   :members:
   :undoc-members:
   :show-inheritance:

Location (Abstract Base Class)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: PASS.general_framework.general_classes.Location
   :members:
   :undoc-members:
   :show-inheritance:

SimpleLocation
^^^^^^^^^^^^^^

.. autoclass:: PASS.general_framework.general_classes.SimpleLocation
   :members:
   :undoc-members:
   :show-inheritance:

LatitudeRange
^^^^^^^^^^^^^

.. autoclass:: PASS.general_framework.general_classes.LatitudeRange
   :members:
   :undoc-members:
   :show-inheritance:

Times
^^^^^

.. autoclass:: PASS.general_framework.general_classes.Times
   :members:
   :undoc-members:
   :show-inheritance:

power_status
------------

Power system status tracking and failure detection.

.. automodule:: PASS.general_framework.power_status
   :members:
   :undoc-members:
   :show-inheritance:

State
^^^^^

.. autoclass:: PASS.general_framework.power_status.State
   :members:
   :undoc-members:
   :show-inheritance:

Failures
^^^^^^^^

.. autoclass:: PASS.general_framework.power_status.Failures
   :members:
   :undoc-members:
   :show-inheritance:

Status
^^^^^^

.. autoclass:: PASS.general_framework.power_status.Status
   :members:
   :undoc-members:
   :show-inheritance:
